/*-------------------------------------------------------------------------
 Testbench module for Luffa_Compact.v

 File name   : Luffa_Compact_TB.v
 Version     : Version 0.1
 Created     : FEB/08/2010
 Last update : FEB/08/2010
 Desgined by : Akashi Satoh
 
 
 Copyright (C) 2010 AIST
 
 By using this code, you agree to the following terms and conditions.
 
 This code is copyrighted by AIST ("us").
 
 Permission is hereby granted to copy, reproduce, redistribute or
 otherwise use this code as long as: there is no monetary profit gained
 specifically from the use or reproduction of this code, it is not sold,
 rented, traded or otherwise marketed, and this copyright notice is
 included prominently in any copy made.
 
 We shall not be liable for any damages, including without limitation
 direct, indirect, incidental, special or consequential damages arising
 from the use of this code.
 
 When you publish any results arising from the use of this code, we will
 appreciate it if you can cite our webpage
 (http://www.rcis.aist.go.jp/special/SASEBO/index-en.html).
 -------------------------------------------------------------------------*/

module Luffa_TB;

  parameter CLOCK = 10;

  reg  CLK;
  reg  RSTn;
  reg  EN;
  reg  Mrdy;
  reg  Init;
  reg  EoM;
  reg  [255:0] M;
  wire BSY;
  wire [255:0] H;

Luffa Luffa(
  .CLK  (CLK),                                              // System clock
  .RSTn (RSTn),                                             // Negative reset
  .EN   (EN),                                               // Enable
  .Mrdy (Mrdy),                                             // Set High for message input
  .Init (Init),                                             // Set High for the first message input
  .EoM  (EoM),                                              // Set High for the last message input
  .M    (M),                                                // Message input
  .BSY  (BSY),                                              // Busy flag
  .H    (H));                                               // Hash output

  parameter MSG0 = 256'h61626380_00000000_00000000_00000000_00000000_00000000_00000000_00000000;
  parameter MD0  = 256'hF29311B8_7E9E40DE_7699BE23_FBEB5A47_CB16EA4F_5556D47C_A40C12AD_764A73BD;

  parameter MSG1 = 256'h538989EE_FA891A2F_2FDB195E_6C75A36F_FD9010B0_D58419CB_209EA581_78284E38;
  parameter MSG2 = 256'h491A0A85_49EECC27_ED31C02E_24DF4321_DAE90E68_67DA8518_98867D29_93997301;
  parameter MD1  = 256'h268E9172_BB676C37_5AE99101_775F0D31_FC8BC364_F3C58E0F_015E2B7D_68F959BA;

  initial CLK = 1;
  always #(CLOCK/2)
    CLK <= ~CLK;

  initial begin

  #(CLOCK/5);
    RSTn <= 0;

  #(CLOCK);
    RSTn <= 1;
    EN   <= 1;
    Init <= 1;
    EoM  <= 1;
    Mrdy <= 1;
    M    <= MSG0;

  #(CLOCK);
    Mrdy <= 0;
    Init <= 0;
    EoM  <= 0;

  #(CLOCK * 55)
    $display("H=%x", H);

  #(CLOCK);
    Init <= 1;
    Mrdy <= 1;
    M    <= MSG1;

  #(CLOCK);
    Mrdy <= 0;
    Init <= 0;

  #(CLOCK*24);
    EoM  <= 1;
    Mrdy <= 1;
    M    <= MSG2;

  #(CLOCK);
    Mrdy <= 0;
    EoM  <= 0;

  #(CLOCK * 55)
    $display("H=%x", H);

  $stop;
  end
endmodule
